PyXMake Developer Guide: PyXMake.VTL.stm_make._BaseTest Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Static Public Attributes | List of all members
PyXMake.VTL.stm_make._BaseTest Class Reference
Inheritance diagram for PyXMake.VTL.stm_make._BaseTest:

## Public Member Functions
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)

## Public Attributes
str | command = "py.test"
| out = None
| covout = None
| verbose = self.distribution.verbose
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Static Public Attributes
str | description = "Runs all unit tests using py.test."
list | user_options

## Additional Inherited Members
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_command (self)
| _run_command (self, command)
| _perform_post_actions (self)
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Base class for all test classes

Definition at line 967 of file stm_make.py.

## Member Function Documentation

## ◆ finalize_options()

PyXMake.VTL.stm_make._BaseTest.finalize_options | ( |  | self | ) |

Definition at line 984 of file stm_make.py.

## ◆ initialize_options()

PyXMake.VTL.stm_make._BaseTest.initialize_options | ( |  | self | ) |

Reimplemented in PyXMake.VTL.stm_make.pyx_pytest.

Definition at line 979 of file stm_make.py.

## Member Data Documentation

## ◆ command

str PyXMake.VTL.stm_make._BaseTest.command = "py.test"

Definition at line 980 of file stm_make.py.

## ◆ covout

PyXMake.VTL.stm_make._BaseTest.covout = None

Definition at line 982 of file stm_make.py.

## ◆ description

str PyXMake.VTL.stm_make._BaseTest.description = "Runs all unit tests using py.test."
| static

Definition at line 971 of file stm_make.py.

## ◆ out

PyXMake.VTL.stm_make._BaseTest.out = None

Definition at line 981 of file stm_make.py.

## ◆ user_options

list PyXMake.VTL.stm_make._BaseTest.user_options
| static

Initial value:
= [
("command=", None, "Path and name of the command line tool."),
("out=", None, "Specifies the output format of the test results." \
+ "Formats: xml, standard out. Default: standard out."),
("covout=", None, "Specifies the output format of the coverage report." \
+ "Formats: xml, html.")]

Definition at line 972 of file stm_make.py.

## ◆ verbose

PyXMake.VTL.stm_make._BaseTest.verbose = self.distribution.verbose

Definition at line 985 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py